/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.bookkeeper.processor;

import org.apache.bookkeeper.proto.BookieRequestHandler;

/**
 * A request processor that is used for processing requests at bookie side.
 */
public interface RequestProcessor extends AutoCloseable {

    /**
     * Close the request processor.
     */
    @Override
    void close();

    /**
     * Process request.
     *
     * @param r
     *          request to process
     * @param channel
     *          channel received the given request <i>r</i>
     */
    void processRequest(Object r, BookieRequestHandler channel);
}
